@@ -1,5 +1,5 @@
 package HackaMol::Angle;
-
+$HackaMol::Angle::VERSION = '0.020';
 #ABSTRACT: Angle class for HackaMol
 use 5.008;
 use Moose;
@@ -9,7 +9,7 @@ use Math::Vector::Real;
 use MooseX::StrictConstructor;
 #use MooseX::Storage;
 #with Storage( 'io' => 'StorableFile' ), 
-with 'HackaMol::NameRole', 'HackaMol::AtomGroupRole';
+with 'HackaMol::Roles::NameRole', 'HackaMol::Roles::AtomGroupRole';
 
 has $_ => (
     is        => 'rw',
@@ -93,7 +93,7 @@ HackaMol::Angle - Angle class for HackaMol
 
 =head1 VERSION
 
-version 0.011
+version 0.020
 
 =head1 SYNOPSIS
 
@@ -234,11 +234,11 @@ L<HackaMol::Dihedral>
 
 =over 4
 
-=item * L<HackaMol::AtomGroupRole>
+=item * L<HackaMol::Roles::AtomGroupRole>
 
-=item * L<HackaMol::NameRole>
+=item * L<HackaMol::Roles::NameRole>
 
-=item * L<HackaMol::NameRole|HackaMol::AtomGroupRole>
+=item * L<HackaMol::Roles::NameRole|HackaMol::Roles::AtomGroupRole>
 
 =back
 
