@@ -1,5 +1,5 @@
 package HackaMol::Atom;
-
+$HackaMol::Atom::VERSION = '0.020';
 #ABSTRACT: HackaMol Atom Class
 use 5.008;
 use Moose;
@@ -8,8 +8,10 @@ use Carp;
 use MooseX::StrictConstructor;
 #use MooseX::Storage;
 #with Storage( 'io' => 'StorableFile' ),
-with  'HackaMol::NameRole', 'HackaMol::PhysVecMVRRole',
-  'HackaMol::PdbRole',  'HackaMol::QmAtomRole';
+with  'HackaMol::Roles::NameRole', 
+      'HackaMol::Roles::PhysVecMVRRole',
+      'HackaMol::Roles::PdbRole',  
+      'HackaMol::Roles::QmAtomRole';
 use HackaMol::PeriodicTable
   qw(@ELEMENTS %ELEMENTS %ATOMIC_MASSES @COVALENT_RADII @VDW_RADII %ATOM_MULTIPLICITY);
 
@@ -176,7 +178,7 @@ HackaMol::Atom - HackaMol Atom Class
 
 =head1 VERSION
 
-version 0.011
+version 0.020
 
 =head1 SYNOPSIS
 
@@ -313,15 +315,15 @@ L<Chemistry::Atom>
 
 =over 4
 
-=item * L<HackaMol::NameRole>
+=item * L<HackaMol::Roles::NameRole>
 
-=item * L<HackaMol::NameRole|HackaMol::PhysVecMVRRole|HackaMol::PdbRole|HackaMol::QmAtomRole>
+=item * L<HackaMol::Roles::NameRole|HackaMol::Roles::PhysVecMVRRole|HackaMol::Roles::PdbRole|HackaMol::Roles::QmAtomRole>
 
-=item * L<HackaMol::PdbRole>
+=item * L<HackaMol::Roles::PdbRole>
 
-=item * L<HackaMol::PhysVecMVRRole>
+=item * L<HackaMol::Roles::PhysVecMVRRole>
 
-=item * L<HackaMol::QmAtomRole>
+=item * L<HackaMol::Roles::QmAtomRole>
 
 =back
 
