@@ -1,5 +1,5 @@
 package HackaMol::AtomGroup;
-
+$HackaMol::AtomGroup::VERSION = '0.018';
 #ABSTRACT: HackaMol AtomGroup class
 use 5.008;
 use Moose;
@@ -8,7 +8,7 @@ use Carp;
 use MooseX::StrictConstructor;
 #use MooseX::Storage;
 #with Storage( 'io' => 'StorableFile' ), 
-with 'HackaMol::NameRole', 'HackaMol::AtomGroupRole';
+with 'HackaMol::Roles::NameRole', 'HackaMol::Roles::AtomGroupRole';
 
 sub Rg {
 
@@ -39,7 +39,7 @@ HackaMol::AtomGroup - HackaMol AtomGroup class
 
 =head1 VERSION
 
-version 0.011
+version 0.018
 
 =head1 SYNOPSIS
 
@@ -112,11 +112,11 @@ L<HackaMol::AtomGroupRole>
 
 =over 4
 
-=item * L<HackaMol::AtomGroupRole>
+=item * L<HackaMol::Roles::AtomGroupRole>
 
-=item * L<HackaMol::NameRole>
+=item * L<HackaMol::Roles::NameRole>
 
-=item * L<HackaMol::NameRole|HackaMol::AtomGroupRole>
+=item * L<HackaMol::Roles::NameRole|HackaMol::Roles::AtomGroupRole>
 
 =back
 
