@@ -1,5 +1,5 @@
 package HackaMol::Molecule;
-$HackaMol::Molecule::VERSION = '0.018';
+
 #ABSTRACT: Molecule class for HackaMol
 use 5.008;
 use Moose;
@@ -10,9 +10,8 @@ use Scalar::Util qw(refaddr);
 use MooseX::StrictConstructor;
 #use MooseX::Storage;
 #with Storage( 'io' => 'StorableFile' ), 
-with 'HackaMol::Roles::PhysVecMVRRole',
-     'HackaMol::Roles::BondsAnglesDihedralsRole', 
-     'HackaMol::Roles::QmMolRole';
+with 'HackaMol::NameRole', 'HackaMol::PhysVecMVRRole',
+  'HackaMol::BondsAnglesDihedralsRole', 'HackaMol::QmMolRole';
 
 extends 'HackaMol::AtomGroup';
 
@@ -218,7 +217,7 @@ HackaMol::Molecule - Molecule class for HackaMol
 
 =head1 VERSION
 
-version 0.018
+version 0.011
 
 =head1 SYNOPSIS
 
@@ -406,15 +405,17 @@ L<Chemistry::Molecule>
 
 =over 4
 
-=item * L<HackaMol::Roles::BondsAnglesDihedralsRole>
+=item * L<HackaMol::BondsAnglesDihedralsRole>
 
-=item * L<HackaMol::Roles::PhysVecMVRRole>
+=item * L<HackaMol::NameRole>
 
-=item * L<HackaMol::Roles::PhysVecMVRRole|HackaMol::Roles::BondsAnglesDihedralsRole|HackaMol::Roles::QmMolRole>
+=item * L<HackaMol::NameRole|HackaMol::PhysVecMVRRole|HackaMol::BondsAnglesDihedralsRole|HackaMol::QmMolRole>
 
-=item * L<HackaMol::Roles::QmAtomRole>
+=item * L<HackaMol::PhysVecMVRRole>
 
-=item * L<HackaMol::Roles::QmMolRole>
+=item * L<HackaMol::QmAtomRole>
+
+=item * L<HackaMol::QmMolRole>
 
 =back
 
